==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAbstractMapper.java <==
// java wrapper for vtkAbstractMapper object
//

package vtk;
import vtk.*;

public class vtkAbstractMapper extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void ReleaseGraphicsResources_3(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_3(id0); }

  private native double GetTimeToDraw_4();
  public double GetTimeToDraw()
    { return GetTimeToDraw_4(); }

  private native void AddClippingPlane_5(vtkPlane id0);
  public void AddClippingPlane(vtkPlane id0)
    { AddClippingPlane_5(id0); }

  private native void RemoveClippingPlane_6(vtkPlane id0);
  public void RemoveClippingPlane(vtkPlane id0)
    { RemoveClippingPlane_6(id0); }

  private native void RemoveAllClippingPlanes_7();
  public void RemoveAllClippingPlanes()
    { RemoveAllClippingPlanes_7(); }

  private native void SetClippingPlanes_8(vtkPlaneCollection id0);
  public void SetClippingPlanes(vtkPlaneCollection id0)
    { SetClippingPlanes_8(id0); }

  private native long GetClippingPlanes_9();
  public vtkPlaneCollection GetClippingPlanes() {
    long temp = GetClippingPlanes_9();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetClippingPlanes_10(vtkPlanes id0);
  public void SetClippingPlanes(vtkPlanes id0)
    { SetClippingPlanes_10(id0); }

  private native void ShallowCopy_11(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_11(id0); }

  public vtkAbstractMapper() { super(); }

  public vtkAbstractMapper(long id) { super(id); }

}

==> vtk-8.0.1-2-aarch64.pkg.tar.xz: vtk/vtkAbstractMapper.java <==
// java wrapper for vtkAbstractMapper object
//

package vtk;
import vtk.*;

public class vtkAbstractMapper extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void ReleaseGraphicsResources_3(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_3(id0); }

  private native double GetTimeToDraw_4();
  public double GetTimeToDraw()
    { return GetTimeToDraw_4(); }

  private native void AddClippingPlane_5(vtkPlane id0);
  public void AddClippingPlane(vtkPlane id0)
    { AddClippingPlane_5(id0); }

  private native void RemoveClippingPlane_6(vtkPlane id0);
  public void RemoveClippingPlane(vtkPlane id0)
    { RemoveClippingPlane_6(id0); }

  private native void RemoveAllClippingPlanes_7();
  public void RemoveAllClippingPlanes()
    { RemoveAllClippingPlanes_7(); }

  private native void SetClippingPlanes_8(vtkPlaneCollection id0);
  public void SetClippingPlanes(vtkPlaneCollection id0)
    { SetClippingPlanes_8(id0); }

  private native long GetClippingPlanes_9();
  public vtkPlaneCollection GetClippingPlanes() {
    long temp = GetClippingPlanes_9();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetClippingPlanes_10(vtkPlanes id0);
  public void SetClippingPlanes(vtkPlanes id0)
    { SetClippingPlanes_10(id0); }

  private native void ShallowCopy_11(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_11(id0); }

  public vtkAbstractMapper() { super(); }

  public vtkAbstractMapper(long id) { super(id); }

}
